@@ -22,7 +22,14 @@ Rcpp::List perfmeas_prec_recall(const Rcpp::IntegerVector& order, const Rcpp::In
   int np = 0;
   std::vector<float> precision(vec_size);
   std::vector<float> recall(vec_size);
-  const unsigned int pos_last = static_cast<unsigned int>(vec_size) - 1;
+  const int pos_last = vec_size - 1;
+
+  if (pos_last < 2) {
+    ret_val["precision"] = precision;
+    ret_val["recall"] = recall;
+
+    return ret_val;
+  }
 
   for (int i = 0; i < vec_size; i++) {
     if (labels[i] == 1) {
